[SCM] Samba Shared Repository - branch master updated - release-4-0-0alpha8-1261-ge3c7e9e

Michael Adam obnox at samba.org
Fri Aug 28 06:29:51 MDT 2009


The branch, master has been updated
       via  e3c7e9e81edf05f6946cac6f07a8bd8d6729adcb (commit)
       via  9f1c162e3374250657e3f90c34df19031bb58c93 (commit)
      from  074c6d4214ca5ae2a71eb8cb62a3cf19a88a39b3 (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=master


- Log -----------------------------------------------------------------
commit e3c7e9e81edf05f6946cac6f07a8bd8d6729adcb
Author: Michael Adam <obnox at samba.org>
Date:   Fri Aug 28 14:09:58 2009 +0200

    s4-ldb: update dlinklist.h to match main copy (lib/util/dlinklist.h)
    
    Michael

commit 9f1c162e3374250657e3f90c34df19031bb58c93
Author: Michael Adam <obnox at samba.org>
Date:   Fri Aug 28 14:06:28 2009 +0200

    s3-ldb: update dlinklist.h to match main copy (lib/util/dlinklist.h)
    
    This also removes build warnings of redefined macros
    since it uses the embracing "#ifndef _DLINKLIST_H ... #endif".
    
    Michael

-----------------------------------------------------------------------

Summary of changes:
 source3/lib/ldb/include/dlinklist.h |   15 +++++++++------
 source4/lib/ldb/include/dlinklist.h |   11 +++++------
 2 files changed, 14 insertions(+), 12 deletions(-)


Changeset truncated at 500 lines:

diff --git a/source3/lib/ldb/include/dlinklist.h b/source3/lib/ldb/include/dlinklist.h
index d325275..62f885d 100644
--- a/source3/lib/ldb/include/dlinklist.h
+++ b/source3/lib/ldb/include/dlinklist.h
@@ -20,6 +20,9 @@
 /* To use these macros you must have a structure containing a next and
    prev pointer */
 
+#ifndef _DLINKLIST_H
+#define _DLINKLIST_H
+
 
 /* hook into the front of the list */
 #define DLIST_ADD(list, p) \
@@ -36,7 +39,6 @@ do { \
 } while (0)
 
 /* remove an element from a list - element doesn't have to be in list. */
-#ifndef DLIST_REMOVE
 #define DLIST_REMOVE(list, p) \
 do { \
 	if ((p) == (list)) { \
@@ -48,7 +50,6 @@ do { \
 	} \
 	if ((p) && ((p) != (list))) (p)->next = (p)->prev = NULL; \
 } while (0)
-#endif
 
 /* promote an element to the top of the list */
 #define DLIST_PROMOTE(list, p) \
@@ -57,7 +58,7 @@ do { \
           DLIST_ADD(list, p); \
 } while (0)
 
 /* hook into the end of the list - needs a tmp pointer */
 #define DLIST_ADD_END(list, p, type) \
 do { \
 		if (!(list)) { \
@@ -86,11 +87,11 @@ do { \
 	}\
 } while (0)
 
 /* demote an element to the end of the list, needs a tmp pointer */
 #define DLIST_DEMOTE(list, p, tmp) \
 do { \
 		DLIST_REMOVE(list, p); \
-		DLIST_ADD_END(list, p, tmp); \
+		DLIST_ADD_END(list, p, type); \
 } while (0)
 
 /* concatenate two lists - putting all elements of the 2nd list at the
@@ -108,3 +109,5 @@ do { \
 			} \
 		} \
 } while (0)
+
+#endif /* _DLINKLIST_H */
@@ -57,7 +58,7 @@ do { \
 } while (0)
 
-/* hook into the end of the list - needs a tmp pointer */
+/* hook into the end of the list - needs the entry type */
 #define DLIST_ADD_END(list, p, type) \
 do { \
@@ -86,11 +87,11 @@ do { \
 } while (0)
 
-/* demote an element to the end of the list, needs a tmp pointer */
-#define DLIST_DEMOTE(list, p, tmp) \
+/* demote an element to the end of the list, needs the entry type */
+#define DLIST_DEMOTE(list, p, type) \
 do { \
 		DLIST_REMOVE(list, p); \
diff --git a/source4/lib/ldb/include/dlinklist.h b/source4/lib/ldb/include/dlinklist.h
index acab9fa..62f885d 100644
--- a/source4/lib/ldb/include/dlinklist.h
+++ b/source4/lib/ldb/include/dlinklist.h
@@ -23,6 +23,7 @@
 #ifndef _DLINKLIST_H
 #define _DLINKLIST_H
 
+
 /* hook into the front of the list */
 #define DLIST_ADD(list, p) \
 do { \
@@ -38,7 +39,6 @@ do { \
 } while (0)
 
 /* remove an element from a list - element doesn't have to be in list. */
-#ifndef DLIST_REMOVE
 #define DLIST_REMOVE(list, p) \
 do { \
 	if ((p) == (list)) { \
@@ -50,7 +50,6 @@ do { \
 	} \
 	if ((p) && ((p) != (list))) (p)->next = (p)->prev = NULL; \
 } while (0)
-#endif
 
 /* promote an element to the top of the list */
 #define DLIST_PROMOTE(list, p) \
@@ -59,7 +58,7 @@ do { \
           DLIST_ADD(list, p); \
 } while (0)
 
 /* hook into the end of the list - needs a tmp pointer */
 #define DLIST_ADD_END(list, p, type) \
 do { \
 		if (!(list)) { \
@@ -88,11 +87,11 @@ do { \
 	}\
 } while (0)
 
 /* demote an element to the end of the list, needs a tmp pointer */
 #define DLIST_DEMOTE(list, p, tmp) \
 do { \
 		DLIST_REMOVE(list, p); \
-		DLIST_ADD_END(list, p, tmp); \
+		DLIST_ADD_END(list, p, type); \
 } while (0)
 
 /* concatenate two lists - putting all elements of the 2nd list at the
@@ -59,7 +58,7 @@ do { \
 } while (0)
 
-/* hook into the end of the list - needs a tmp pointer */
+/* hook into the end of the list - needs the entry type */
 #define DLIST_ADD_END(list, p, type) \
 do { \
@@ -88,11 +87,11 @@ do { \
 } while (0)
 
-/* demote an element to the end of the list, needs a tmp pointer */
-#define DLIST_DEMOTE(list, p, tmp) \
+/* demote an element to the end of the list, needs the entry type */
+#define DLIST_DEMOTE(list, p, type) \
 do { \
 		DLIST_REMOVE(list, p); \


-- 
Samba Shared Repository


More information about the samba-cvs mailing list